@@ -3,10 +3,7 @@ import asyncio
 import logging
 import sys
 from argparse import ArgumentParser
-from typing import (
-    List,
-    ValuesView,
-)
+from typing import List, ValuesView
 
 from pyvelop.const import _PACKAGE_VERSION
 from pyvelop.device import Device
@@ -124,14 +121,12 @@ async def main() -> None:
             _LOGGER.error("Timeout connecting to %s", args.primary_node)
         else:
             if args.target == "mesh":
-                # region #-- general details --#
-                if all_args:
-                    _LOGGER.debug("Processing general details")
-                    section = "Overview"
-                    section += f"\n{'-' * len(section)}\n"
-                    section += f"Update Mode: {_mesh.update_type}\n"
-                    section += f"Speedtest Status: {_mesh.speedtest_status or 'N/A'}"
-                    sections.append(section)
+                # region #-- overview --#
+                _LOGGER.debug("Preparing mesh overview details")
+                section = "Overview"
+                section += f"\n{'-' * len(section)}\n"
+                section += f"Firmware Update: {_mesh.firmware_update_setting}"
+                sections.append(section)
                 # endregion
 
                 # region #-- get the node names --#
@@ -185,7 +180,7 @@ async def main() -> None:
                     sections.append(section)
                 # endregion
 
-                # region #-- get available storage --#
+                # region #-- get the storage server settings --#
                 if args.get_available_storage or all_args:
                     _LOGGER.debug("Preparing available storage")
                     section = "Available Storage"
@@ -198,13 +193,12 @@ async def main() -> None:
                 # region #-- get the latest Speedtest results --#
                 if args.get_latest_speedtest or all_args:
                     _LOGGER.debug("Preparing latest Speedtest results")
-                    latest_results = _mesh.speedtest_results
+                    latest_results = _mesh.latest_speedtest_result
                     section = "Latest Speedtest Results"
                     section += f"\n{'-' * len(section)}\n"
-                    if not latest_results:
+                    if latest_results is None:
                         section += "None available"
                     else:
-                        latest_results = latest_results[0]
                         download_bandwidth = round(latest_results.get('download_bandwidth') / 1024, 2)
                         upload_bandwidth = round(latest_results.get('upload_bandwidth') / 1024, 2)
                         section += f"Executed: {latest_results.get('timestamp')}\n"\
@@ -263,11 +257,12 @@ async def main() -> None:
 
                     # region #-- get the overview details --#
                     if args.get_overview or all_args:
-                        _LOGGER.debug("Preparing ndoe overview details")
+                        _LOGGER.debug("Preparing node overview details")
                         section = "Overview"
                         section += f"\n{'-' * len(section)}\n"
                         section += f"Device ID: {_node.unique_id}\n"\
                                    f"Name: {_node.name}\n"\
+                                   f"Results Time: {_node.results_time}\n"\
                                    f"Online: {_node.status}\n"\
                                    f"IP: {','.join([adapter.get('ip') for adapter in _node.connected_adapters])}\n"\
                                    f"Type: {_node.type.title()}\n"\
@@ -332,8 +327,8 @@ async def main() -> None:
                             section = "Overview"
                             section += f"\n{'-' * len(section)}\n"
                             section += f"Device ID: {_d.unique_id}\n"\
-                                       f"Last Queried: {_d.results_time}\n"\
                                        f"Name: {_d.name}\n" \
+                                       f"Results Time: {_d.results_time}\n" \
                                        f"Manufacturer: {_d.manufacturer}\n" \
                                        f"Model: {_d.model}\n" \
                                        f"Description: {_d.description}\n" \
